iamserviceaccount

package
v1.2.61-rc2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 27, 2026 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CreateIamServiceAccountUserOptions

type CreateIamServiceAccountUserOptions struct {
	ServiceAccountNames []string
	Namespace           string
	RoleName            string
	PolicyArns          []string
	InlinePolicy        string
	PermissionsBoundary string
	Path                string
}

func BuildIamServiceAccountCreateCommandWithOptions

func BuildIamServiceAccountCreateCommandWithOptions() (*cobra.Command, *CreateIamServiceAccountUserOptions)

func NewCreateIamServiceAccountUserOptions

func NewCreateIamServiceAccountUserOptions() *CreateIamServiceAccountUserOptions

type DeleteIamServiceAccountUserOptions

type DeleteIamServiceAccountUserOptions struct {
	ServiceAccountName string
	Namespace          string
	RoleName           string
}

func BuildIamServiceAccountDeleteCommandWithOptions

func BuildIamServiceAccountDeleteCommandWithOptions() (*cobra.Command, *DeleteIamServiceAccountUserOptions)

func NewDeleteIamServiceAccountUserOptions

func NewDeleteIamServiceAccountUserOptions() *DeleteIamServiceAccountUserOptions

type DescribeIamServiceAccountUserOptions

type DescribeIamServiceAccountUserOptions struct {
	ServiceAccountName string
	Namespace          string
	RoleName           string
}

func BuildIamServiceAccountDescribeCommandWithOptions

func BuildIamServiceAccountDescribeCommandWithOptions() (*cobra.Command, *DescribeIamServiceAccountUserOptions)

func NewDescribeIamServiceAccountUserOptions

func NewDescribeIamServiceAccountUserOptions() *DescribeIamServiceAccountUserOptions

func (*DescribeIamServiceAccountUserOptions) GenerateRoleNameIfNeeded

func (opts *DescribeIamServiceAccountUserOptions) GenerateRoleNameIfNeeded(clusterName string) error

GenerateRoleNameIfNeeded generates a role name based on cluster, namespace, and service account

func (*DescribeIamServiceAccountUserOptions) ValidateAndPromptForInputs

func (opts *DescribeIamServiceAccountUserOptions) ValidateAndPromptForInputs(r *rosa.Runtime, cmd *cobra.Command) error

ValidateAndPromptForInputs validates user inputs and prompts for missing required values

func (*DescribeIamServiceAccountUserOptions) ValidateCluster

func (opts *DescribeIamServiceAccountUserOptions) ValidateCluster(cluster *v1.Cluster) error

ValidateCluster validates that the cluster supports IAM service accounts

Jump to